@@ -11,7 +11,7 @@
 # You can redistribute it and/or modify it under the terms of the
 # GPL2, GNU General Public License version 2.
 #
-# $Id: Rss2imap.pm,v 1.5 2005/10/07 16:19:51 mumumu-org Exp $
+# $Id: Rss2imap.pm,v 1.7 2005/10/09 05:37:24 mumumu-org Exp $
 #
 
 require 5.008_000;
@@ -209,11 +209,14 @@ package RSS2IMAPLIB::Rss2imap;
 
             my $message_id  = $this->gen_message_id ($rss, $item);
 
+            #    if expire enabled, get lastest-modified time of rss.
             if ($this->{site_config}->{expire} > 0) {
                 my $rss_date = $this->get_date ($rss, $item);
                 next if (time() - HTTP::Date::str2time ($rss_date) > $this->{site_config}->{expire} * 60 * 60 * 24);
             }
 
+            #   message id is "rss url@host" AND x-rss-aggregator field is "rss2imap"
+            #   and not deleted.
             my @search = $imap->search ("NOT DELETED HEADER message-id \"$message_id\" HEADER x-rss-aggregator \"rss2imap\"");
 
             if ($this->is_error()) {
@@ -221,13 +224,20 @@ package RSS2IMAPLIB::Rss2imap;
                 next;
             }
 
+            #    if message not found, append it.
             if (@search == 0) {
                 print " appending $message_id\n";
                 push @append_items, $item;
             } else {
+
+                #    get last-modified date of rss
                 my $rss_date = $this->get_rss_date ($rss, $item);
                 next unless ($rss_date); # date filed is not found, we ignore it.
+                #    get last-modified_date of IMAP search result.
                 my $latest = $this->get_latest_date (\@search);
+
+                #    if rss date is newer, delete search result and add rss items.
+                #    by this, duplicate message is replaced with lastest one.
                 if (HTTP::Date::str2time ($rss_date) > $latest) {
                     print " updateing $message_id\n";
                     push @delete_mail, @search;
@@ -238,7 +248,7 @@ package RSS2IMAPLIB::Rss2imap;
             }
         }
 
-        # delete items
+        #    delete items, if sync functionality is enabled
         if ($this->{site_config}->{'sync'}) {
             my %found = ();
             for my $item (@items) {
@@ -445,7 +455,7 @@ BODY
 
         my $subject    = $this->{site_config}->{subject};
         my $from       = $this->{site_config}->{from};
-        my $desc       = $item->{description} || "";
+        my $desc       = $this->get_description( $item );
         ($subject, $from) = $this->apply_template ($rss, $item, undef, $subject, $from);
 
         #  convert html tag to appropriate text.
@@ -472,7 +482,7 @@ BODY
 
         my $subject    = $this->{site_config}->{subject};
         my $from       = $this->{site_config}->{from};
-        my $desc       = $item->{description} || "";
+        my $desc       = $this->get_description( $item );
         ($subject, $from) = $this->apply_template ($rss, $item, undef, $subject, $from);
 
         my $return_body =<<"BODY"
@@ -595,10 +605,25 @@ BODY
 
 
     sub get_rss_date {
+
         my $this = shift;
         my $rss  = shift;
         my $item = shift;
-        return $item->{dc}->{date} || $rss->{channel}->{dc}->{date} || $rss->{'rss2imap:last-modified'};
+
+        #    priority of rss last-modified-date is ...
+        #    1. item -> 2. channel -> 3. http header.
+        #    http header is the last resort!
+        #
+        #    dc:date is derived from rss 1.0 specification
+        #    pubDate, lastbuilddate are derived from rss 0.91 rev 3, rss 2.0
+        #
+        return $item->{dc}->{date}
+            || $item->{pubDate}
+            || $item->{date}       # this is not valid attribute!
+            || $rss->{channel}->{dc}->{date}
+            || $rss->{channel}->{lastBuildDate}
+            || $rss->{channel}->{pubDate}
+            || undef;
     }
 
 
@@ -611,6 +636,31 @@ BODY
     }
 
 
+    sub get_description {
+
+        my $this = shift;
+        my $item = shift;
+        my $return_desc = "";
+
+        $return_desc = $item->{description} if ($item->{description});
+
+        #   rss 1.0 module content
+        my $module10_uri = "http://purl.org/rss/1.0/modules/content/";
+        my $content_encoded = $item->{$module10_uri}->{encoded};
+
+        $return_desc = $content_encoded if ($content_encoded);
+
+        #   rss 1.0 Dublin Core:Description
+        $return_desc = $item->{dc}->{description} if ($item->{dc}->{description});
+
+        chomp $return_desc;
+        $return_desc =~ s/^\s*//;
+        $return_desc =~ s/\s*$//;
+
+        return $return_desc;
+    }
+
+
     sub get_real_folder_name {
         my $this = shift;
         my $str  = shift;
