@@ -16,7 +16,7 @@ use Jcode;
 # You can redistribute it and/or modify it under the terms of the
 # GPL2, GNU General Public License version 2.
 #
-# $Id: Unicode.pm,v 1.3 2005/10/06 16:34:18 mumumu-org Exp $
+# $Id: Unicode.pm,v 1.4 2005/11/19 19:19:18 mumumu-org Exp $
 #
 
 
@@ -41,7 +41,10 @@ package RSS2IMAPLIB::Unicode;
         my $s       = shift;
         my $fromenc = lc(shift);
 
-        return $s if( $fromenc =~ /utf.*8/i );
+        #    there is an sucks rss which report encoding as utf-8
+        #    even if encoding is not so! we try to convert
+        #    to utf-8 even if encoding is reported as utf-8
+        $fromenc = undef if( $fromenc =~ /utf.*8/i );
 
         if( $fromenc ) {
             Encode::from_to($s, $fromenc,'utf8');
